==> dde-daemon_6.0.48.tar.xz: BUILD/misc/ts/org.deepin.dde.fprintd.policy/policy_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>Une authentification est requise pour ajouter une empreinte comme mot de passe</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>Ajouter une empreinte comme mot de passe</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>Une authentification est requise pour effacer les empreintes enregistrées</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>Effacer les empreintes enregistrées</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation>Une authentification est requise pour renommer une empreinte</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation>Renommer une empreinte digitale</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation>Mot de passe requis pour effectuer cette action</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation>Gérer les empreintes</translation>
		</message>
	</context>
</TS>

==> dde-daemon_6.1.45.tar.xz: BUILD/misc/ts/org.deepin.dde.fprintd.policy/policy_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>Une authentification est requise pour ajouter une empreinte digitale comme mot de passe</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>Ajouter une empreinte digitale comme mot de passe</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>Une authentification est requise pour effacer les empreintes digitales enregistrées</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>Effacer les empreintes digitales enregistrées</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation>Une authentification est requise pour changer le mot de passe d&apos;une empreinte digitale</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation>Changer le mot de passe d&apos;une empreinte digitale</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation>Mot de passe requis pour effectuer cette action</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation>Gérer les empreintes digitales</translation>
		</message>
	</context>
</TS>
